@@ -13,11 +13,11 @@ use Scalar::Util qw(blessed);
 
 # Constants.
 Readonly::Array our @EXPORT_OK => qw{parse serialize};
-Readonly::Scalar our $LOG_REGEXP => qr{(\d{4}-\d{2}-\d{2})\s+(\d{2}:\d{2}:\d{2}\.\d+)\s+\[(\w+)\]\s+([^:]+):(\d+)\s+(.*)};
+Readonly::Scalar our $LOG_REGEXP => qr{(\d{4}-\d{2}-\d{2})\s+(\d{2}:\d{2}:\d{2}\.?\d*)\s+\[(\w+)\]\s+([^:]+):(\d+)\s+(.*)};
 Readonly::Scalar our $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.06;
 
 # Parse FreeSWITCH log line.
 sub parse {
@@ -54,7 +54,10 @@ sub serialize {
 		$SPACE.$data_o->time.
 		$SPACE.'['.$data_o->type.']'.
 		$SPACE.$data_o->file.':'.$data_o->file_line.
-		$SPACE.$data_o->message;
+		$SPACE;
+	if (defined $data_o->message) {
+		$data .= $data_o->message;
+	}
 	$data_o->raw($data);
 	return $data;
 }
@@ -171,6 +174,16 @@ L<Log::FreeSWITCH::Line::Data>,
 L<Readonly>,
 L<Scalar::Util>.
 
+=head1 SEE ALSO
+
+=over
+
+=item L<Log::FreeSWITCH::Line::Data>
+
+Data object which represents FreeSWITCH log line.
+
+=back
+
 =head1 REPOSITORY
 
 L<https://github.com/tupinek/Log-FreeSWITCH-Line>
@@ -188,6 +201,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.04
+0.06
 
 =cut
