@@ -11,7 +11,7 @@ use Error::Pure qw(err);
 use Mo qw(builder is required);
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.06;
 
 has date => (
 	'is' => 'ro',
@@ -242,7 +242,13 @@ L<Mo>.
 
 =head1 SEE ALSO
 
-L<Log::FreeSWITCH::Line::Data>.
+=over
+
+=item L<Log::FreeSWITCH::Line>
+
+FreeSWITCH log line parsing and serializing.
+
+=back
 
 =head1 REPOSITORY
 
@@ -261,6 +267,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.04
+0.06
 
 =cut
